;;; elisp-insert.el --- init package for gnorb

;; Copyright (C) 2017 Uwe Brauer

;; Author: Uwe Brauer oub@mat.ucm.es
;; Maintainer: Uwe Brauer oub@mat.ucm.es
;; Created: 21 Feb 2017
;; Version: 1.0
;; Keywords:

 
;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 1, or (at your option)
;; any later version.

;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; A copy of the GNU General Public License can be obtained from this
;; program's author (send electronic mail to oub@mat.ucm.es) or from
;; the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA
;; 02139, USA.

;; LCD Archive Entry:
;; gnorb-init|Uwe Brauer|oub@mat.ucm.es
;; |init package for gnorb
;; |$Date$|$Revision$|~/packages/gnorb-init.el

;;; Commentary:

;;; Change log:
;; $Log$

;;; Code:


;; gnorb

(require 'gnorb-registry)
(use-package gnorb
  :defer 5
  :bind (:map  message-mode-map ("C-c t" . gnorb-gnus-outgoing-do-todo))
  :config
  (use-package init-gnus :config (setq gnus-registry-install t)
               (setq gnorb-gnus-new-todo-capture-key "t")
               (gnorb-tracking-initialize))

  (use-package gnorb-bbdb
    :init
    (setq gnorb-org-agenda-popup-bbdb t)
    :bind (
           ;; ("C-c C" . gnorb-bbdb-cite-contact)
           :map bbdb-mode-map
                ("O" . gnorb-bbdb-tag-agenda)
                ("S" . gnorb-bbdb-mail-search)
                ;;                ([remap bbdb-mail] . gnorb-bbdb-mail)
                ("l" . gnorb-bbdb-open-link)))

  (use-package gnorb-org
    :bind (
           :map org-mode-map
                ("C-c C" . gnorb-org-contact-link)
                ("C-c t" . gnorb-org-handle-mail)
                ("C-c e" . gnorb-org-view)
                ("C-c E" . gnorb-org-email-subtree)
                ("C-c V" . gnorb-org-popup-bbdb))
    (:map org-agenda-mode-map
          ("H" . gnorb-org-handle-mail)
          ("V" . gnorb-org-popup-bbdb)))
  (use-package gnorb-gnus
    :bind (
           :map gnus-summary-mime-map ("a" . gnorb-gnus-article-org-attach))
    (:map gnus-summary-mode-map ("C-c t" . gnorb-gnus-incoming-do-todo))
    :config
    (push '("attach to org heading" . gnorb-gnus-mime-org-attach)
          gnus-mime-action-alist)
    ;; The only way to add mime button command keys is by redefining
    ;; gnus-mime-button-map, possibly not ideal. Ideal would be a
    ;; setter function in gnus itself.
    (push '(gnorb-gnus-mime-org-attach "a" "Attach to Org heading")
          gnus-mime-button-commands)
    (setq gnus-mime-button-map
          (let ((map (make-sparse-keymap)))
;            (define-key map gnus-mouse-2 'gnus-article-push-button)
;            (define-key map gnus-down-mouse-3 'gnus-mime-button-menu)
            (dolist (c gnus-mime-button-commands)
              (define-key map (cadr c) (car c)))
            map)))) 


 
 (eval-after-load "gnorb-org"
   '(progn
      (org-defkey org-mode-map (kbd "C-c C") 'gnorb-org-contact-link)
      (org-defkey org-mode-map (kbd "C-c t") 'gnorb-org-handle-mail)
      (org-defkey org-mode-map (kbd "C-c e") 'gnorb-org-view)
      (org-defkey org-mode-map (kbd "C-c E") 'gnorb-org-email-subtree)
      (org-defkey org-mode-map (kbd "C-c V") 'gnorb-org-popup-bbdb)
      (setq gnorb-org-agenda-popup-bbdb t)
      (eval-after-load "org-agenda"
        '(progn (org-defkey org-agenda-mode-map (kbd "C-c t") 'gnorb-org-handle-mail)
                (org-defkey org-agenda-mode-map (kbd "C-c v") 'gnorb-org-popup-bbdb)
                (org-defkey org-agenda-mode-map (kbd "V") 'gnorb-org-view)))))
 
 (eval-after-load "gnorb-gnus"
   '(progn
      (define-key gnus-summary-mime-map "a" 'gnorb-gnus-article-org-attach)
      (define-key gnus-summary-mode-map (kbd "C-c t") 'gnorb-gnus-incoming-do-todo)
      (push '("attach to org heading" . gnorb-gnus-mime-org-attach)
            gnus-mime-action-alist)
      ;; The only way to add mime button command keys is by redefining
      ;; gnus-mime-button-map, possibly not ideal. Ideal would be a
      ;; setter function in gnus itself.
      (push '(gnorb-gnus-mime-org-attach "a" "Attach to Org heading")
            gnus-mime-button-commands)
      (setq gnus-mime-button-map
            (let ((map (make-sparse-keymap)))
;              (define-key map gnus-mouse-2 'gnus-article-push-button)
;              (define-key map gnus-down-mouse-3 'gnus-mime-button-menu)
              (dolist (c gnus-mime-button-commands)
                (define-key map (cadr c) (car c)))
              map))))
 
 (eval-after-load "message"
   '(progn
      (define-key message-mode-map (kbd "C-c t") 'gnorb-gnus-outgoing-do-todo)))

(setq gnorb-gnus-sent-groups "nnml+archive:sent-mail")
(provide 'gnorb-init)
;;; GNORB-INIT.EL ends here
